Gromacs core modules — GromacsWrapper 0.5.0-dev documentation

# Gromacs core modules

This section documents the modules, classes, and functions on which the other parts of the package rely. The information is probably mostly relevant to anyone who wants to extend the package.

- `gromacs.core` – Core functionality
- `gromacs.config` – Configuration for GromacsWrapper
- `gromacs.environment` – Run time modification of behaviour
- `gromacs.formats` – Accessing various files
- `gromacs.utilities` – Helper functions and classes
- `gromacs.tools` – Gromacs commands classes